/*
    This file is part of Curv library
    Copyright 2018 by Kzen Networks
    (https://github.com/KZen-networks/curv)
    License MIT: https://github.com/KZen-networks/curv/blob/master/LICENSE
*/

pub mod feldman_vss;
mod polynomial;

pub use polynomial::{Polynomial, PolynomialDegree};
